@@ -1,4 +1,5 @@
 from kikit import panelize
+from kikit.panel_features.copperFill import HatchedCopperFill, HexCopperFill, SolidCopperFill
 from kikit.panelize_ui import Section, PresetError
 from kikit.panelize import *
 from kikit.defs import Layer
@@ -500,11 +501,12 @@ def buildTooling(preset, panel):
         hoffset, voffset = toolingPreset["hoffset"], toolingPreset["voffset"]
         diameter = toolingPreset["size"]
         paste = toolingPreset["paste"]
+        soldermaskmargin = toolingPreset["soldermaskmargin"]
         if type == "3hole":
-            panel.addCornerTooling(3, hoffset, voffset, diameter, paste)
+            panel.addCornerTooling(3, hoffset, voffset, diameter, paste, soldermaskmargin)
             return
         if type == "4hole":
-            panel.addCornerTooling(4, hoffset, voffset, diameter, paste)
+            panel.addCornerTooling(4, hoffset, voffset, diameter, paste, soldermaskmargin)
             return
         raise PresetError(f"Unknown type '{type}' of tooling specification.")
     except KeyError as e:
@@ -579,20 +581,29 @@ def buildCopperfill(preset, panel):
         if type == "none":
             return
         if type == "solid":
-            panel.copperFillNonBoardAreas(
+            panel.apply(SolidCopperFill(
                 clearance=preset["clearance"],
+                edgeclearance=preset["edgeclearance"],
                 layers=preset["layers"],
-                hatched=False
-            )
+            ))
         if type == "hatched":
-            panel.copperFillNonBoardAreas(
-                    clearance=preset["clearance"],
-                    layers=preset["layers"],
-                    hatched=True,
-                    strokeWidth=preset["width"],
-                    strokeSpacing=preset["spacing"],
-                    orientation=preset["orientation"]
-            )
+            panel.apply(HatchedCopperFill(
+                clearance=preset["clearance"],
+                edgeclearance=preset["edgeclearance"],
+                layers=preset["layers"],
+                strokeWidth=preset["width"],
+                strokeSpacing=preset["spacing"],
+                orientation=preset["orientation"]
+            ))
+        if type == "hex":
+            panel.apply(HexCopperFill(
+                clearance=preset["clearance"],
+                edgeclearance=preset["edgeclearance"],
+                layers=preset["layers"],
+                diameter=preset["diameter"],
+                space=preset["spacing"],
+                threshold=preset["threshold"]
+            ))
     except KeyError as e:
         raise PresetError(f"Missing parameter '{e}' in section 'postprocessing'")
 
